#[non_exhaustive]pub enum SwitchError {
ExpectedError,
SwitchNotFound,
NotInit,
UsbBadInterface(u8),
LinuxEnv,
AccessDenied,
PlatformNotSupported,
WindowsWrongDriver(WindowsDriver),
UdevRulesNotFound,
Usb(String),
}Expand description
An error interacting with the Switch in RCM mode
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ExpectedError
Expected to get a timeout after smashing the stack but we did not
SwitchNotFound
Cannot find a switch in RCM mode connected
NotInit
Usb device was not initialized
UsbBadInterface(u8)
Unable to claim the Switches interface
LinuxEnv
A linux environment error such as not having the correct usb driver support
AccessDenied
USB permission error See https://github.com/budde25/switcheroo#linux-permission-denied-error
PlatformNotSupported
Running on an unsupported platform
WindowsWrongDriver(WindowsDriver)
A Windows error that the switch RCM has the wrong driver, please install libusbK See https://github.com/budde25/switcheroo#windows-wrong-driver-error
UdevRulesNotFound
udev rules not installed
Usb(String)
This is a catchall error for various other things that can go wrong with underlying usb library. It has been converted to a string to not expose the underlying api